@@ -5,30 +5,30 @@ C   was funded by the NASA Radiation Science Program.
 C   The code can be used without limitations in any not-for-       
 C   profit scientific research.  The only request is that in any      
 C   publication using the code the source of the code be acknowledged  
-C   and relevant references be made. 
+C   and relevant references be made.
 
 C   This version code has been modified by Cory Davis (University 
-C   of Edinburgh) for inclusion in the the PyARTS atmospheric radiative 
-C   transfer package                                  
+C   of Edinburgh) for inclusion in the the ARTS and PyARTS atmospheric
+C   radiative transfer packages
 
 ! OLE 13/06/27: Add RAT as parameter to Tmatrix subroutine. Renamed
 ! subroutines that have names collisions with tmd.arts.f.
 ! Use LaPACK version of TT subroutine from ampld.lp.f.
 
-! CPD 10/09/03: Have realised that the tmarix subroutine includes useful
+! CPD 03/09/10: Have realised that the tmarix subroutine includes useful
 !calculations for randomly oriented particles.  Included Cext and Csca
 !as output variables`
 
-! CPD 18/12/02: Added the input variable 'quiet' to the Tmatrix
+! CPD 02/12/18: Added the input variable 'quiet' to the Tmatrix
 ! subroutine.  quiet = 1 disables any standard output, unless something
 ! unusual happens that you probably need to know about.
 
-! CPD 31/10/02:  This file represents my attempt to carve MIM's code so
+! CPD 02/10/31:  This file represents my attempt to carve MIM's code so
 !that the T-matrix may be calculated once for a given particle.  The
 !large preamble has been deleted - refer to ampld.lp.f
 !Step 1: Chop original ampld subroutine before the AMPL call.  Calling
 !the first half Tmatrix
-!Step 2: Remove irrelevent arguements.  At this point I will keep the
+!Step 2: Remove irrelevent arguments.  At this point I will keep the
 !COMMONS, so any program that calls these subs, will need these
 !declarations
 
@@ -60,7 +60,7 @@ C      DDELT=0.001D0
 
       P=DACOS(-1D0)
 C      ICHOICE=1 only for use with NAG libraries  
-      ICHOICE=1 	
+      ICHOICE=1
       NCHECK=0
       IF (NP.EQ.-1.OR.NP.EQ.-2) NCHECK=1
       IF (NP.GT.0.AND.(-1)**NP.EQ.1) NCHECK=1
@@ -73,15 +73,15 @@ C      ICHOICE=1 only for use with NAG libraries
 C     PRINT 8000, RAT
 C 8000 FORMAT ('RAT=',F8.6)
       if (quiet /= 1) then
-		IF(NP.EQ.-1.AND.EPS.GE.1D0) PRINT 7000,EPS
-      	IF(NP.EQ.-1.AND.EPS.LT.1D0) PRINT 7001,EPS
-      	IF(NP.GE.0) PRINT 7100,NP,EPS
-      	IF(NP.EQ.-2.AND.EPS.GE.1D0) PRINT 7150,EPS
-      	IF(NP.EQ.-2.AND.EPS.LT.1D0) PRINT 7151,EPS
-      	IF(NP.EQ.-3) PRINT 7160
-      	PRINT 7400, LAM,MRR,MRI
-      	PRINT 7200,DDELT
-	end if
+        IF(NP.EQ.-1.AND.EPS.GE.1D0) PRINT 7000,EPS
+        IF(NP.EQ.-1.AND.EPS.LT.1D0) PRINT 7001,EPS
+        IF(NP.GE.0) PRINT 7100,NP,EPS
+        IF(NP.EQ.-2.AND.EPS.GE.1D0) PRINT 7150,EPS
+        IF(NP.EQ.-2.AND.EPS.LT.1D0) PRINT 7151,EPS
+        IF(NP.EQ.-3) PRINT 7160
+        PRINT 7400, LAM,MRR,MRI
+        PRINT 7200,DDELT
+      end if
  7000 FORMAT('OBLATE SPHEROIDS, A/B=',F11.7)
  7001 FORMAT('PROLATE SPHEROIDS, A/B=',F11.7)
  7100 FORMAT('CHEBYSHEV PARTICLES, T',
@@ -111,7 +111,7 @@ C 8000 FORMAT ('RAT=',F8.6)
       DO 50 NMA=INM1,NPN1
 
          NMAX=NMA
-	   MMAX=1
+         MMAX=1
          NGAUSS=NMAX*NDGS
          IF (NGAUSS.GT.NPNG1) THEN
             WRITE (ERRMSG, 7340) NGAUSS
@@ -263,11 +263,11 @@ c     PRINT 7800,0,DABS(QEXT),QSCA,NMAX
  9111 FORMAT ('WARNING: W IS GREATER THAN 1, W = ',D12.6)
 !Calculate Scattering cross-section and extinction cross-section
 !for randomly oriented particles
-	CSCA=QSCA*LAM**2/2/P
-	CEXT=-QEXT*LAM**2/2/P
+      CSCA=QSCA*LAM**2/2/P
+      CEXT=-QEXT*LAM**2/2/P
 
-	RETURN
-	END	
+      RETURN
+      END
 
 C********************************************************************
                                            
@@ -289,13 +289,34 @@ C   CALCULATION OF THE AMPLITUDE MATRIX
       COMPLEX*16 CAL(NPN4,NPN4),VV,VH,HV,HH
       COMMON /TMAT/ TR11,TR12,TR21,TR22,TI11,TI12,TI21,TI22
 
-      IF (ALPHA.LT.0D0.OR.ALPHA.GT.360D0.OR.
-     &    BETA.LT.0D0.OR.BETA.GT.180D0.OR.
-     &    TL.LT.0D0.OR.TL.GT.180D0.OR.
-     &    TL1.LT.0D0.OR.TL1.GT.180D0.OR.
-     &    PL.LT.0D0.OR.PL.GT.360D0.OR.
-     &    PL1.LT.0D0.OR.PL1.GT.360D0) THEN 
-          WRITE (6,2000)
+c      IF (ALPHA.LT.0D0.OR.ALPHA.GT.360D0.OR.
+c     &    BETA.LT.0D0.OR.BETA.GT.180D0.OR.
+c     &    TL.LT.0D0.OR.TL.GT.180D0.OR.
+c     &    TL1.LT.0D0.OR.TL1.GT.180D0.OR.
+c     &    PL.LT.0D0.OR.PL.GT.360D0.OR.
+c     &    PL1.LT.0D0.OR.PL1.GT.360D0) THEN 
+c          WRITE (6,2000)
+c          STOP
+c      ELSE
+c          CONTINUE
+c      ENDIF  
+      IF (ALPHA.LT.0D0.OR.ALPHA.GT.360D0) THEN
+          WRITE (6,'(A,F6.1)') 'ALPHA OUTSIDE RANGE: ', ALPHA
+          STOP
+      ELSE IF (BETA.LT.0D0.OR.BETA.GT.180D0) THEN
+          WRITE (6,'(A,F6.1)') 'BETA OUTSIDE RANGE: ', BETA
+          STOP
+      ELSE IF (TL.LT.0D0.OR.TL.GT.180D0) THEN
+          WRITE (6,'(A,F6.1)') 'THETA0 OUTSIDE RANGE: ', TL
+          STOP
+      ELSE IF (TL1.LT.0D0.OR.TL1.GT.180D0) THEN
+          WRITE (6,'(A,F6.1)') 'THETA OUTSIDE RANGE: ', TL1
+          STOP
+      ELSE IF (PL.LT.0D0.OR.PL.GT.360D0) THEN
+          WRITE (6,'(A,F6.1)') 'PHI0 OUTSIDE RANGE: ', PL
+          STOP
+      ELSE IF (PL1.LT.0D0.OR.PL1.GT.360D0) THEN 
+          WRITE (6,'(A,F6.1)') 'PHI OUTSIDE RANGE: ', PL1
           STOP
       ELSE
           CONTINUE
@@ -1578,9 +1599,9 @@ C     Matrix inversion from LAPACK
            ENDDO
       ENDDO
       INFO=0
-      CALL ZGETRF(NNMAX,NNMAX,ZQ,NPN2,IPIV,INFO)
+      CALL TMZGETRF(NNMAX,NNMAX,ZQ,NPN2,IPIV,INFO)
       IF (INFO.NE.0) WRITE (6,1100) INFO
-      CALL ZGETRI(NNMAX,ZQ,NPN2,IPIV,ZW,NPN2,INFO)
+      CALL TMZGETRI(NNMAX,ZQ,NPN2,IPIV,ZW,NPN2,INFO)
       IF (INFO.NE.0) WRITE (6,1100) INFO
 
  1100 FORMAT ('WARNING:  info=', i2)
