@@ -1336,10 +1336,10 @@ C	Inversion from NAG-LIB or Waterman's method
 	IF (ICHOICE.EQ.1) THEN
 	   INFO=0
 C           CALL F07ARF(NNMAX,NNMAX,ZQ,NPN2,IPIV,INFO)
-           CALL ZGETRF(NNMAX,NNMAX,ZQ,NPN2,IPIV,INFO)
+           CALL TMZGETRF(NNMAX,NNMAX,ZQ,NPN2,IPIV,INFO)
 C          IF (INFO.NE.0) WRITE (6,1100) INFO
 C           CALL F07AWF(NNMAX,ZQ,NPN2,IPIV,ZW,NPN2,INFO)
-           CALL ZGETRI(NNMAX,ZQ,NPN2,IPIV,ZW,NPN2,INFO)
+           CALL TMZGETRI(NNMAX,ZQ,NPN2,IPIV,ZW,NPN2,INFO)
 C           IF (INFO.NE.0) WRITE (6,1100) INFO
  1100      FORMAT ('WARNING:  info=', i2)
 	   DO I=1,NNMAX
