@@ -15,7 +15,6 @@
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
    USA. */
 
-
 ////////////////////////////////////////////////////////////////////////////
 //   File description
 ////////////////////////////////////////////////////////////////////////////
@@ -28,54 +27,68 @@
 
 */
 
+#include "bofstream.h"
 #include <fstream>
 #include <stdexcept>
-#include "bofstream.h"
 
-void bofstream::seek(long spos, Offset offs)
-{
-  if(!in) { err = NotOpen; return; }
-
-  switch(offs) {
-  case Set: this->seekp(spos, ios::beg); break;
-  case Add: this->seekp(spos, ios::cur); break;
-  case End: this->seekp(spos, ios::end); break;
-  }
-}
-
-streampos bofstream::pos()
-{
-  if(!in) { err = NotOpen; return 0; }
-  return streamoff (this->tellp ());
-}
-
-void bofstream::putByte (bofstream::Byte b)
-{
-  if(!this->good ()) {
-    err |= NotOpen;
-    throw runtime_error ("Cannot open binary file for writing");
+void bofstream::seek(long spos, Offset offs) {
+  if (!in) {
+    err = NotOpen;
     return;
   }
 
-  this->put (b);
-  if (this->bad ())
-    {
-      err |= Fatal;
-      throw runtime_error ("Writing to binary file failed");
-    }
+  switch (offs) {
+    case Set:
+      this->seekp(spos, ios::beg);
+      break;
+    case Add:
+      this->seekp(spos, ios::cur);
+      break;
+    case End:
+      this->seekp(spos, ios::end);
+      break;
+  }
 }
 
+streampos bofstream::pos() {
+  if (!in) {
+    err = NotOpen;
+    return 0;
+  }
+  return streamoff(this->tellp());
+}
+
+void bofstream::putByte(bofstream::Byte b) {
+  if (!this->good()) {
+    err |= NotOpen;
+    throw runtime_error("Cannot open binary file for writing");
+    return;
+  }
+
+  this->put(b);
+  if (this->bad()) {
+    err |= Fatal;
+    throw runtime_error("Writing to binary file failed");
+  }
+}
 
 /* Overloaded output operators */
-bofstream& operator<< (bofstream& bof, double n)
-{ bof.writeFloat (n, binio::Double); return (bof); }
+bofstream& operator<<(bofstream& bof, double n) {
+  bof.writeFloat(n, binio::Double);
+  return (bof);
+}
 
-bofstream& operator<< (bofstream& bof, float n)
-{ bof.writeFloat (n, binio::Double); return (bof); }
+bofstream& operator<<(bofstream& bof, float n) {
+  bof.writeFloat(n, binio::Double);
+  return (bof);
+}
 
-bofstream& operator<< (bofstream& bof, long n)
-{ bof.writeInt (n, 4); return (bof); }
-
-bofstream& operator<< (bofstream& bof, int n)
-{ bof.writeInt (n, 4); return (bof); }
+bofstream& operator<<(bofstream& bof, long n) {
+  bof.writeInt(n, 4);
+  return (bof);
+}
 
+bofstream& operator<<(bofstream& bof, int n) {
+  bof.writeInt(n, 4);
+  return (bof);
+}
