@@ -35,17 +35,15 @@
   === External declarations
   ===========================================================================*/
 
-
-#include <stdexcept>
+#include "gridded_fields.h"
 #include <iostream>
+#include <stdexcept>
 #include "exceptions.h"
 #include "mystring.h"
-#include "gridded_fields.h"
-
 
+using std::endl;
 using std::ostream;
 using std::ostringstream;
-using std::endl;
 using std::runtime_error;
 
 /*===========================================================================
@@ -58,29 +56,25 @@ using std::runtime_error;
 
   \param[in] gf Source gridded field
 */
-void GriddedField::copy_grids(const GriddedField& gf)
-{
+void GriddedField::copy_grids(const GriddedField& gf) {
   assert(gf.get_dim() == dim);
 
-  for (Index i = 0; i < dim; i++)
-    {
-      switch (gf.get_grid_type(i))
-        {
-        case GRID_TYPE_NUMERIC:
-          mgridtypes[i] = GRID_TYPE_NUMERIC;
-          mnumericgrids[i] = gf.get_numeric_grid(i);
-          mstringgrids[i].resize(0);
-          break;
-        case GRID_TYPE_STRING:
-          mgridtypes[i] = GRID_TYPE_STRING;
-          mstringgrids[i] = gf.get_string_grid(i);
-          mnumericgrids[i].resize(0);
-          break;
-        }
+  for (Index i = 0; i < dim; i++) {
+    switch (gf.get_grid_type(i)) {
+      case GRID_TYPE_NUMERIC:
+        mgridtypes[i] = GRID_TYPE_NUMERIC;
+        mnumericgrids[i] = gf.get_numeric_grid(i);
+        mstringgrids[i].resize(0);
+        break;
+      case GRID_TYPE_STRING:
+        mgridtypes[i] = GRID_TYPE_STRING;
+        mstringgrids[i] = gf.get_string_grid(i);
+        mnumericgrids[i].resize(0);
+        break;
     }
+  }
 }
 
-
 //! Get a numeric grid.
 /*!
   Returns the numeric grid with index i.
@@ -90,30 +84,26 @@ void GriddedField::copy_grids(const GriddedField& gf)
   \param[in]  i  Grid index.
   \return        Numeric grid.
 */
-ConstVectorView GriddedField::get_numeric_grid(Index i) const
-{
-  assert (i < dim);
-  if (mgridtypes[i] != GRID_TYPE_NUMERIC)
-    {
-      ostringstream os;
+const Vector& GriddedField::get_numeric_grid(Index i) const {
+  assert(i < dim);
+  if (mgridtypes[i] != GRID_TYPE_NUMERIC) {
+    ostringstream os;
 
-      if (mname.length())
-        os << mname << " ";
+    if (mname.length()) os << mname << " ";
 
-      os << "Grid ";
-      if (mgridnames[i].length())
-        os << mgridnames[i];
-      else
-        os << i;
-      os << " is not a numeric grid.";
+    os << "Grid ";
+    if (mgridnames[i].length())
+      os << mgridnames[i];
+    else
+      os << i;
+    os << " is not a numeric grid.";
 
-      throw runtime_error(os.str());
-    }
+    throw runtime_error(os.str());
+  }
 
-  return (mnumericgrids[i]);
+  return mnumericgrids[i];
 }
 
-
 //! Get a numeric grid.
 /*!
   Returns the numeric grid with index i.
@@ -123,30 +113,26 @@ ConstVectorView GriddedField::get_numeric_grid(Index i) const
   \param[in]  i  Grid index.
   \return        Numeric grid.
 */
-VectorView GriddedField::get_numeric_grid(Index i)
-{
-  assert (i < dim);
-  if (mgridtypes[i] != GRID_TYPE_NUMERIC)
-    {
-      ostringstream os;
+Vector& GriddedField::get_numeric_grid(Index i) {
+  assert(i < dim);
+  if (mgridtypes[i] != GRID_TYPE_NUMERIC) {
+    ostringstream os;
 
-      if (mname.length())
-        os << mname << " ";
+    if (mname.length()) os << mname << " ";
 
-      os << "Grid ";
-      if (mgridnames[i].length())
-        os << mgridnames[i];
-      else
-        os << i;
-      os << " is not a numeric grid.";
+    os << "Grid ";
+    if (mgridnames[i].length())
+      os << mgridnames[i];
+    else
+      os << i;
+    os << " is not a numeric grid.";
 
-      throw runtime_error(os.str());
-    }
+    throw runtime_error(os.str());
+  }
 
-  return (mnumericgrids[i]);
+  return mnumericgrids[i];
 }
 
-
 //! Get a string grid.
 /*!
   Returns the string grid with index i.
@@ -156,31 +142,26 @@ VectorView GriddedField::get_numeric_grid(Index i)
   \param[in]  i  Grid index.
   \return        String grid.
 */
-const ArrayOfString& GriddedField::get_string_grid(Index i) const
-{
-  assert (i < dim);
-  if (mgridtypes[i] != GRID_TYPE_STRING)
-    {
-      ostringstream os;
+const ArrayOfString& GriddedField::get_string_grid(Index i) const {
+  assert(i < dim);
+  if (mgridtypes[i] != GRID_TYPE_STRING) {
+    ostringstream os;
 
-      if (mname.length())
-        os << mname << " ";
+    if (mname.length()) os << mname << " ";
 
-      os << "Grid ";
-      if (mgridnames[i].length())
-        os << mgridnames[i];
-      else
-        os << i;
-      os << " is not a string grid.";
-
-      throw runtime_error(os.str());
-    }
+    os << "Grid ";
+    if (mgridnames[i].length())
+      os << mgridnames[i];
+    else
+      os << i;
+    os << " is not a string grid.";
 
+    throw runtime_error(os.str());
+  }
 
   return (mstringgrids[i]);
 }
 
-
 //! Get a string grid.
 /*!
   Returns the string grid with index i.
@@ -190,31 +171,26 @@ const ArrayOfString& GriddedField::get_string_grid(Index i) const
   \param[in]  i  Grid index.
   \return        String grid.
 */
-ArrayOfString& GriddedField::get_string_grid(Index i)
-{
-  assert (i < dim);
-  if (mgridtypes[i] != GRID_TYPE_STRING)
-    {
-      ostringstream os;
+ArrayOfString& GriddedField::get_string_grid(Index i) {
+  assert(i < dim);
+  if (mgridtypes[i] != GRID_TYPE_STRING) {
+    ostringstream os;
 
-      if (mname.length())
-        os << mname << " ";
+    if (mname.length()) os << mname << " ";
 
-      os << "Grid ";
-      if (mgridnames[i].length())
-        os << mgridnames[i];
-      else
-        os << i;
-      os << " is not a string grid.";
-
-      throw runtime_error(os.str());
-    }
+    os << "Grid ";
+    if (mgridnames[i].length())
+      os << mgridnames[i];
+    else
+      os << i;
+    os << " is not a string grid.";
 
+    throw runtime_error(os.str());
+  }
 
   return (mstringgrids[i]);
 }
 
-
 //! Set a numeric grid.
 /*!
   Sets grid i to the given grid.
@@ -222,15 +198,13 @@ ArrayOfString& GriddedField::get_string_grid(Index i)
   \param[in]  i  Grid index.
   \param[in]  g  New grid.
 */
-void GriddedField::set_grid(Index i, const Vector& g)
-{
-  assert (i < dim);
+void GriddedField::set_grid(Index i, const Vector& g) {
+  assert(i < dim);
   mgridtypes[i] = GRID_TYPE_NUMERIC;
   mstringgrids[i].resize(0);
   mnumericgrids[i] = g;
 }
 
-
 //! Set a string grid.
 /*!
   Sets grid i to the given grid.
@@ -238,15 +212,13 @@ void GriddedField::set_grid(Index i, const Vector& g)
   \param[in] i Grid index.
   \param[in] g New grid.
 */
-void GriddedField::set_grid(Index i, const ArrayOfString& g)
-{
-  assert (i < dim);
+void GriddedField::set_grid(Index i, const ArrayOfString& g) {
+  assert(i < dim);
   mgridtypes[i] = GRID_TYPE_STRING;
   mnumericgrids[i].resize(0);
   mstringgrids[i] = g;
 }
 
-
 //! Output operator for GriddedField
 /*!
  Outputs the grids for the given GriddedField.
@@ -254,74 +226,55 @@ void GriddedField::set_grid(Index i, const ArrayOfString& g)
  \param[in,out]  os  Output stream.
  \param[in]      gf  GriddedField.
  */
-ostream& operator<<(ostream& os, const GriddedField& gf)
-{
+ostream& operator<<(ostream& os, const GriddedField& gf) {
   if (gf.mname.size()) os << gf.mname << ":" << endl;
 
-  for( Index i = 0; i < gf.dim; i++)
-    {
-      if (gf.mgridnames[i].size()) os << gf.mgridnames[i];
-      else os << "Grid " << i;
-      os << ": ";
-      switch (gf.mgridtypes[i])
-        {
-        case GRID_TYPE_STRING:
-          os << gf.mstringgrids[i];
-          break;
-        case GRID_TYPE_NUMERIC:
-          os << gf.mnumericgrids[i];
-          break;
-        }
-      os << endl;
+  for (Index i = 0; i < gf.dim; i++) {
+    if (gf.mgridnames[i].size())
+      os << gf.mgridnames[i];
+    else
+      os << "Grid " << i;
+    os << ": ";
+    switch (gf.mgridtypes[i]) {
+      case GRID_TYPE_STRING:
+        os << gf.mstringgrids[i];
+        break;
+      case GRID_TYPE_NUMERIC:
+        os << gf.mnumericgrids[i];
+        break;
     }
+    os << endl;
+  }
 
   return os;
 }
 
-
 //! See GriddedField::operator<<
-ostream& operator<<(ostream& os, const GriddedField1& gf)
-{
+ostream& operator<<(ostream& os, const GriddedField1& gf) {
   return os << *((GriddedField*)&gf) << "Data:" << endl << gf.data << endl;
 }
 
-
 //! See GriddedField::operator<<
-ostream& operator<<(ostream& os, const GriddedField2& gf)
-{
-  return os << *((GriddedField*)&gf) << "Data:" << endl << gf.data;
+ostream& operator<<(ostream& os, const GriddedField2& gf) {
+  return os << *((GriddedField*)&gf) << "Data:" << endl << gf.data << endl;
 }
 
-
 //! See GriddedField::operator<<
-ostream& operator<<(ostream& os, const GriddedField3& gf)
-{
-  return os << *((GriddedField*)&gf) << "Data:" << endl << gf.data;
+ostream& operator<<(ostream& os, const GriddedField3& gf) {
+  return os << *((GriddedField*)&gf) << "Data:" << endl << gf.data << endl;
 }
 
-
 //! See GriddedField::operator<<
-ostream& operator<<(ostream& os, const GriddedField4& gf)
-{
-  return os << *((GriddedField*)&gf) << "Data:" << endl << gf.data;
+ostream& operator<<(ostream& os, const GriddedField4& gf) {
+  return os << *((GriddedField*)&gf) << "Data:" << endl << gf.data << endl;
 }
 
-
 //! See GriddedField::operator<<
-ostream& operator<<(ostream& os, const GriddedField5& gf)
-{
-  return os << *((GriddedField*)&gf) << "Data:" << endl << gf.data;
+ostream& operator<<(ostream& os, const GriddedField5& gf) {
+  return os << *((GriddedField*)&gf) << "Data:" << endl << gf.data << endl;
 }
 
-
 //! See GriddedField::operator<<
-ostream& operator<<(ostream& os, const GriddedField6& gf)
-{
-  return os << *((GriddedField*)&gf) << "Data:" << endl << gf.data;
+ostream& operator<<(ostream& os, const GriddedField6& gf) {
+  return os << *((GriddedField*)&gf) << "Data:" << endl << gf.data << endl;
 }
-
-
-
-
-
-
