@@ -16,8 +16,6 @@
    USA.
  */
 
-
-
 ////////////////////////////////////////////////////////////////////////////
 //   File description
 ////////////////////////////////////////////////////////////////////////////
@@ -36,41 +34,37 @@
 #include "arts.h"
 #include "matpackI.h"
 
-Numeric
-legendre_poly (Index l, Index m, Numeric x);
+typedef struct {
+  size_t n;        /* number of points */
+  double* x;       /* Gauss abscissae/points */
+  double* w;       /* Gauss weights for each abscissae */
+  int precomputed; /* high precision abscissae/weights precomputed? */
+} gsl_integration_glfixed_table;
 
-Numeric
-legendre_poly_norm_schmidt (Index l, Index m, Numeric x);
+Numeric legendre_poly(Index l, Index m, Numeric x);
 
-Numeric
-legendre_poly_deriv (Index l, Index m, Numeric x);
+Numeric legendre_poly_norm_schmidt(Index l, Index m, Numeric x);
 
-Numeric
-legendre_poly_norm_schmidt_deriv (Index l, Index m, Numeric x);
+Numeric legendre_poly_deriv(Index l, Index m, Numeric x);
 
-Numeric
-g_legendre_poly (Index l, Index m, Numeric x);
+Numeric legendre_poly_norm_schmidt_deriv(Index l, Index m, Numeric x);
 
-Numeric
-g_legendre_poly_norm_schmidt (Index l, Index m, Numeric x);
+Numeric g_legendre_poly(Index l, Index m, Numeric x);
 
-Numeric
-g_legendre_poly_deriv (Index l, Index m, Numeric x);
+Numeric g_legendre_poly_norm_schmidt(Index l, Index m, Numeric x);
 
-Numeric
-g_legendre_poly_norm_schmidt_deriv (Index l, Index m, Numeric x);
+Numeric g_legendre_poly_deriv(Index l, Index m, Numeric x);
 
-Numeric
-g_legendre_poly_norm_schmidt_deriv1 (Index l, Index m, Numeric x);
+Numeric g_legendre_poly_norm_schmidt_deriv(Index l, Index m, Numeric x);
 
-Numeric
-g_legendre_poly_norm_schmidt_deriv2 (Index l, Index m, Numeric x);
+Numeric g_legendre_poly_norm_schmidt_deriv1(Index l, Index m, Numeric x);
 
-Numeric
-g_legendre_poly_norm_schmidt_deriv3 (Index l, Index m, Numeric x);
+Numeric g_legendre_poly_norm_schmidt_deriv2(Index l, Index m, Numeric x);
 
-Numeric
-g_legendre_poly_norm_schmidt_deriv4 (Index l, Index m, Numeric x);
+Numeric g_legendre_poly_norm_schmidt_deriv3(Index l, Index m, Numeric x);
 
-#endif  /* legendre_h */
+Numeric g_legendre_poly_norm_schmidt_deriv4(Index l, Index m, Numeric x);
 
+bool gsl_integration_glfixed_table_alloc(Vector& x, Vector& w, Index n);
+
+#endif /* legendre_h */
