@@ -1,4 +1,4 @@
-/* Copyright (C) 2006-2012 Oliver Lemke <olemke@core-dump.info>
+/* Copyright (C) 2006-2019 Oliver Lemke <olemke@core-dump.info>
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -15,13 +15,17 @@
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
    USA. */
 
+/**
+    \file   matpack.h
+    \author Stefan Buehler
+*/
+
 #ifndef matpack_h
 #define matpack_h
 
-#include "config_global.h"
+#include "config.h"
 #include "debug.h"
 
-
 //--------------------< Set floating point type >--------------------
 /** The type to use for all floating point numbers. You should never
     use float or double explicitly, unless you have a very good
@@ -34,13 +38,4 @@ typedef NUMERIC Numeric;
     reason. Always use this type instead.  */
 typedef INDEX Index;
 
-// In C++ 11 isnan and isinf were introduced.
-// This confuses g++ because it can't decide whether to
-// call the old functions or the new ones
-#if (__cplusplus >= 201103L)
-#include <cmath>
-#define isnan std::isnan
-#define isinf std::isinf
-#endif
-
-#endif    // matpackI_h
+#endif  // matpackI_h
