@@ -15,7 +15,6 @@
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
    USA. */
 
-
 ////////////////////////////////////////////////////////////////////////////
 //   File description
 ////////////////////////////////////////////////////////////////////////////
@@ -28,7 +27,7 @@
 
 */
 
-#include "config_global.h"
+#include "config.h"
 
 #ifdef ENABLE_NETCDF
 
@@ -38,7 +37,6 @@
 #include "nc_io.h"
 #include "nc_io_types.h"
 
-
 //=== GasAbsLookup ==========================================================
 
 //! Reads a GasAbsLookup table from a NetCDF file
@@ -48,14 +46,15 @@
  
  \author Oliver Lemke
 */
-void nca_read_from_file(const int ncid, GasAbsLookup& gal, const Verbosity&)
-{
+void nca_read_from_file(const int ncid, GasAbsLookup& gal, const Verbosity&) {
   nca_get_data_ArrayOfArrayOfSpeciesTag(ncid, "species", gal.species, true);
-  if (!gal.species.nelem()) throw runtime_error("No species found in lookup table file!");
-  
-  nca_get_data_ArrayOfIndex(ncid, "nonlinear_species", gal.nonlinear_species, true);
+  if (!gal.species.nelem())
+    throw runtime_error("No species found in lookup table file!");
+
+  nca_get_data_ArrayOfIndex(
+      ncid, "nonlinear_species", gal.nonlinear_species, true);
   nca_get_data_Vector(ncid, "f_grid", gal.f_grid, true);
-  nca_get_data_Vector(ncid, "p_grid", gal.p_grid, true);  
+  nca_get_data_Vector(ncid, "p_grid", gal.p_grid, true);
   nca_get_data_Matrix(ncid, "vmrs_ref", gal.vmrs_ref, true);
   nca_get_data_Vector(ncid, "t_ref", gal.t_ref, true);
   nca_get_data_Vector(ncid, "t_pert", gal.t_pert, true);
@@ -63,7 +62,6 @@ void nca_read_from_file(const int ncid, GasAbsLookup& gal, const Verbosity&)
   nca_get_data_Tensor4(ncid, "xsec", gal.xsec, true);
 }
 
-
 //! Writes a GasAbsLookup table to a NetCDF file
 /*!
  \param[in]  ncid    NetCDF file descriptor
@@ -71,60 +69,75 @@ void nca_read_from_file(const int ncid, GasAbsLookup& gal, const Verbosity&)
  
  \author Oliver Lemke
 */
-void nca_write_to_file(const int ncid, const GasAbsLookup& gal, const Verbosity&)
-{
+void nca_write_to_file(const int ncid,
+                       const GasAbsLookup& gal,
+                       const Verbosity&) {
   int retval;
-  
+
   int species_strings_varid;
   int species_count_varid;
-  
+
   ArrayOfIndex species_count(gal.species.nelem());
   Index species_max_strlen = 0;
   char* species_strings = NULL;
-  
-  if (gal.species.nelem())
-    {
-      long species_total_nelems = 0;
-      for (Index nspecies = 0; nspecies < gal.species.nelem(); nspecies++)
-        {
-          Index nspecies_nelem = gal.species[nspecies].nelem();
-          species_total_nelems += nspecies_nelem;
-          species_count[nspecies] = nspecies_nelem;
 
-          for (ArrayOfSpeciesTag::const_iterator it = gal.species[nspecies].begin();
-               it != gal.species[nspecies].end(); it++)
-            if (it->Name().nelem() > species_max_strlen) species_max_strlen = it->Name().nelem();
-        }
-      species_max_strlen++;
+  if (gal.species.nelem()) {
+    long species_total_nelems = 0;
+    for (Index nspecies = 0; nspecies < gal.species.nelem(); nspecies++) {
+      Index nspecies_nelem = gal.species[nspecies].nelem();
+      species_total_nelems += nspecies_nelem;
+      species_count[nspecies] = nspecies_nelem;
 
-      species_strings = new char[species_total_nelems*species_max_strlen];
-      memset(species_strings, 0, species_total_nelems*species_max_strlen);
-
-      Index str_i = 0;
-      for (ArrayOfArrayOfSpeciesTag::const_iterator it1 = gal.species.begin();
-           it1 != gal.species.end(); it1++)
-        for (ArrayOfSpeciesTag::const_iterator it2 = it1->begin();
-             it2 != it1->end(); it2++)
-          {
-            memccpy(&species_strings[str_i], it2->Name().c_str(), 0, species_max_strlen);
-            str_i += species_max_strlen;
-          }
-
-      species_count_varid = nca_def_ArrayOfIndex(ncid, "species_count", species_count);
-
-      int species_strings_ncdims[2];
-      nca_def_dim(ncid, "species_strings_nelem", species_total_nelems, &species_strings_ncdims[0]);
-      nca_def_dim(ncid, "species_strings_length", species_max_strlen, &species_strings_ncdims[1]);
-      nca_def_var(ncid, "species_strings", NC_CHAR, 2, &species_strings_ncdims[0],
-                  &species_strings_varid);
+      for (ArrayOfSpeciesTag::const_iterator it = gal.species[nspecies].begin();
+           it != gal.species[nspecies].end();
+           it++)
+        if (it->Name().nelem() > species_max_strlen)
+          species_max_strlen = it->Name().nelem();
     }
-  else {
-      throw runtime_error("Current lookup table contains no species!");
-    }
-  
+    species_max_strlen++;
+
+    species_strings = new char[species_total_nelems * species_max_strlen];
+    memset(species_strings, 0, species_total_nelems * species_max_strlen);
+
+    Index str_i = 0;
+    for (ArrayOfArrayOfSpeciesTag::const_iterator it1 = gal.species.begin();
+         it1 != gal.species.end();
+         it1++)
+      for (ArrayOfSpeciesTag::const_iterator it2 = it1->begin();
+           it2 != it1->end();
+           it2++) {
+        memccpy(&species_strings[str_i],
+                it2->Name().c_str(),
+                0,
+                species_max_strlen);
+        str_i += species_max_strlen;
+      }
+
+    species_count_varid =
+        nca_def_ArrayOfIndex(ncid, "species_count", species_count);
+
+    int species_strings_ncdims[2];
+    nca_def_dim(ncid,
+                "species_strings_nelem",
+                species_total_nelems,
+                &species_strings_ncdims[0]);
+    nca_def_dim(ncid,
+                "species_strings_length",
+                species_max_strlen,
+                &species_strings_ncdims[1]);
+    nca_def_var(ncid,
+                "species_strings",
+                NC_CHAR,
+                2,
+                &species_strings_ncdims[0],
+                &species_strings_varid);
+  } else {
+    throw runtime_error("Current lookup table contains no species!");
+  }
+
   // Define dimensions and variables
-  int nonlinear_species_varid = nca_def_ArrayOfIndex(ncid, "nonlinear_species",
-                                                     gal.nonlinear_species);
+  int nonlinear_species_varid =
+      nca_def_ArrayOfIndex(ncid, "nonlinear_species", gal.nonlinear_species);
   int f_grid_varid = nca_def_Vector(ncid, "f_grid", gal.f_grid);
   int p_grid_varid = nca_def_Vector(ncid, "p_grid", gal.p_grid);
   int vmrs_ref_varid = nca_def_Matrix(ncid, "vmrs_ref", gal.vmrs_ref);
@@ -132,20 +145,21 @@ void nca_write_to_file(const int ncid, const GasAbsLookup& gal, const Verbosity&
   int t_pert_varid = nca_def_Vector(ncid, "t_pert", gal.t_pert);
   int nls_pert_varid = nca_def_Vector(ncid, "nls_pert", gal.nls_pert);
   int xsec_varid = nca_def_Tensor4(ncid, "xsec", gal.xsec);
-  
+
   if ((retval = nc_enddef(ncid))) nca_error(retval, "nc_enddef");
-  
+
   // Write variables
   nca_put_var_ArrayOfIndex(ncid, species_count_varid, species_count);
-  if (gal.species.nelem())
-    {
-      if ((retval = nc_put_var_text(ncid, species_strings_varid, species_strings)))
-        nca_error(retval, "nc_put_var");
-    }
+  if (gal.species.nelem()) {
+    if ((retval =
+             nc_put_var_text(ncid, species_strings_varid, species_strings)))
+      nca_error(retval, "nc_put_var");
+  }
 
   delete[] species_strings;
-  
-  nca_put_var_ArrayOfIndex(ncid, nonlinear_species_varid, gal.nonlinear_species);
+
+  nca_put_var_ArrayOfIndex(
+      ncid, nonlinear_species_varid, gal.nonlinear_species);
   nca_put_var_Vector(ncid, f_grid_varid, gal.f_grid);
   nca_put_var_Vector(ncid, p_grid_varid, gal.p_grid);
   nca_put_var_Matrix(ncid, vmrs_ref_varid, gal.vmrs_ref);
@@ -155,19 +169,16 @@ void nca_write_to_file(const int ncid, const GasAbsLookup& gal, const Verbosity&
   nca_put_var_Tensor4(ncid, xsec_varid, gal.xsec);
 }
 
-
 ////////////////////////////////////////////////////////////////////////////
 //   Dummy funtion for groups for which
 //   IO function have not yet been implemented
 ////////////////////////////////////////////////////////////////////////////
 
-#define TMPL_NC_READ_WRITE_FILE_DUMMY(what) \
-  void nca_write_to_file(const int, const what&, const Verbosity&) \
-  { \
+#define TMPL_NC_READ_WRITE_FILE_DUMMY(what)                                   \
+  void nca_write_to_file(const int, const what&, const Verbosity&) {          \
     throw runtime_error("NetCDF support not yet implemented for this type!"); \
-  } \
-  void nca_read_from_file(const int, what&, const Verbosity&) \
-  { \
+  }                                                                           \
+  void nca_read_from_file(const int, what&, const Verbosity&) {               \
     throw runtime_error("NetCDF support not yet implemented for this type!"); \
   }
 
@@ -179,4 +190,3 @@ TMPL_NC_READ_WRITE_FILE_DUMMY(Agenda)
 #undef TMPL_NC_READ_WRITE_FILE_DUMMY
 
 #endif /* ENABLE_NETCDF */
-
