@@ -26,25 +26,28 @@
   
 */
 
-#include <iostream>
-#include <cmath>
-#include <stdexcept>
 #include <sys/time.h>
+#include <cmath>
+#include <iostream>
+#include <stdexcept>
 
-#include "arts.h"
 #include "array.h"
+#include "arts.h"
+#include "logic.h"
 #include "math_funcs.h"
 #include "matpackI.h"
-#include "logic.h"
 
 extern const Numeric DEG2RAD;
 extern const Numeric PI;
 
-void init_xy(float stepsize, int frequency,
-             Matrix& Integrand, Vector& za_grid, Vector& aa_grid);
+void init_xy(float stepsize,
+             int frequency,
+             Matrix& Integrand,
+             Vector& za_grid,
+             Vector& aa_grid);
 
-void init_x(int vsize, float stepsize, int frequency,
-            Vector& Integrand, Vector& Theta);
+void init_x(
+    int vsize, float stepsize, int frequency, Vector& Integrand, Vector& Theta);
 
 Numeric AngIntegrate_trapezoid_original(MatrixView Integrand,
                                         ConstVectorView za_grid,
@@ -76,36 +79,39 @@ Numeric AngIntegrate_trapezoid_fixedstep(ConstVectorView Integrand,
                                          ConstVectorView za_grid,
                                          Numeric stepsize);
 
-Numeric test_xy(int z_size, int a_size,
-                float stepsize, int frequency);
+Numeric test_xy(int z_size, int a_size, float stepsize, int frequency);
 
-Numeric test_xy_opt(int z_size, int a_size,
-                    float stepsize, int frequency);
+Numeric test_xy_opt(int z_size, int a_size, float stepsize, int frequency);
 
-Numeric test_xy_fixedstep(int z_size, int a_size,
-                          float stepsize, int frequency);
+Numeric test_xy_fixedstep(int z_size,
+                          int a_size,
+                          float stepsize,
+                          int frequency);
 
-Numeric test_xy_fixedstep_opt(int z_size, int a_size,
-                              float stepsize, int frequency);
+Numeric test_xy_fixedstep_opt(int z_size,
+                              int a_size,
+                              float stepsize,
+                              int frequency);
 
-Numeric test_xy_fixedstep_opt2(int z_size, int a_size,
-                               float stepsize, int frequency);
+Numeric test_xy_fixedstep_opt2(int z_size,
+                               int a_size,
+                               float stepsize,
+                               int frequency);
 
-Numeric test_AngIntegrate_trapezoid_opti(int z_size, int a_size,
-                                         float stepsize, int frequency);
+Numeric test_AngIntegrate_trapezoid_opti(int z_size,
+                                         int a_size,
+                                         float stepsize,
+                                         int frequency);
 
-Numeric test_x(int vsize,
-               float stepsize,
-               int frequency);
+Numeric test_x(int vsize, float stepsize, int frequency);
 
-Numeric test_x_fixedstep(int vsize,
-                         int frequency);
+Numeric test_x_fixedstep(int vsize, int frequency);
 
-
-int main(int argc, char *argv[])
-{
-  if (argc == 1)
-    { cerr << argv[0] << " requires one parameter" << endl; exit (1); }
+int main(int argc, char* argv[]) {
+  if (argc == 1) {
+    cerr << argv[0] << " requires one parameter" << endl;
+    exit(1);
+  }
 
   cout << "Uebergabewert von argv : " << argv[1] << endl;
 
@@ -129,15 +135,16 @@ int main(int argc, char *argv[])
   //  test_xy_fixedstep_opt2(19, 37, 10, frequency);
 }
 
-
 //! init_x
 /*!
   This function fills a Vector with funcition values
   The function is y=x
  */
-void init_x(int vsize, float stepsize, int frequency,
-            Vector& Integrand, Vector& Theta)
-{
+void init_x(int vsize,
+            float stepsize,
+            int frequency,
+            Vector& Integrand,
+            Vector& Theta) {
   cout << "----------------init_x---------------\n";
 
   //  Integrand.resize(vsize); // function to be integrated
@@ -147,8 +154,7 @@ void init_x(int vsize, float stepsize, int frequency,
     Integrand[i] = (float)i * stepsize;
 
   //Theta is between 0 and 180
-  for (int i = 0; i < Theta.nelem(); i++)
-    Theta[i] = (float)i * stepsize;
+  for (int i = 0; i < Theta.nelem(); i++) Theta[i] = (float)i * stepsize;
 
   cout << "function Y = X" << endl
        << "vsize = " << vsize << endl
@@ -156,44 +162,42 @@ void init_x(int vsize, float stepsize, int frequency,
        << "frequency = " << frequency << endl
        << "Integrand: von " << Integrand[0] << " bis "
        << Integrand[Integrand.nelem() - 1] << endl
-       << "Theta: von " << Theta[0] << " bis "
-       << Theta[Theta.nelem() - 1] << endl;
+       << "Theta: von " << Theta[0] << " bis " << Theta[Theta.nelem() - 1]
+       << endl;
 }
 
-
 //! init_xy
 /*!
   This function fills Matrix with funcition values
   The funcion is a circle around 0
  */
-void init_xy(float stepsize, int frequency,
-          Matrix& Integrand, Vector& za_grid, Vector& aa_grid)
-{
+void init_xy(float stepsize,
+             int frequency,
+             Matrix& Integrand,
+             Vector& za_grid,
+             Vector& aa_grid) {
   cout << ">>>>>-----------init_xy---------------\n";
   Index n_za = za_grid.nelem();
   Index n_aa = aa_grid.nelem();
 
   // The r=1 so we get a circle
   for (Index i = 0; i < n_za; i++)
-    for (Index j = 0; j < n_aa; j++)
-      Integrand(i,j)=1;
+    for (Index j = 0; j < n_aa; j++) Integrand(i, j) = 1;
 
   //za_grid (Theta) is between 0 and 180
-  for (Index i = 0; i < n_za; i++)
-    za_grid[i] = (float)i * stepsize;
+  for (Index i = 0; i < n_za; i++) za_grid[i] = (float)i * stepsize;
 
   //aa_grid (Phi) is between 0 and 360
-  for (Index i = 0; i < n_aa; i++)
-    aa_grid[i] = (float)i * stepsize;
+  for (Index i = 0; i < n_aa; i++) aa_grid[i] = (float)i * stepsize;
 
   cout << "function x^2 + y^2 + z^2 = 1" << endl
        << "n_za = " << n_za << endl
        << "n_aa = " << n_aa << endl
        << "stepsize = " << stepsize << endl
        << "frequency = " << frequency << endl
-       << "Integrand(*,0): von " << Integrand(0,0) << " bis "
+       << "Integrand(*,0): von " << Integrand(0, 0) << " bis "
        << Integrand(n_za - 1, 0) << endl
-       << "Integrand(0,*): von " << Integrand(0,0) << " bis "
+       << "Integrand(0,*): von " << Integrand(0, 0) << " bis "
        << Integrand(0, n_aa - 1) << endl
        << "za_grid (Theta): von " << za_grid[0] << " bis "
        << za_grid[za_grid.nelem() - 1] << endl
@@ -202,7 +206,6 @@ void init_xy(float stepsize, int frequency,
   cout << "---------------init_xy---------------<<<<<\n";
 }
 
-
 //! AngIntegrate_trapezoid_original
 /*! 
     The original function from math_funcs.cc
@@ -217,31 +220,26 @@ void init_xy(float stepsize, int frequency,
 */
 Numeric AngIntegrate_trapezoid_original(MatrixView Integrand,
                                         ConstVectorView za_grid,
-                                        ConstVectorView aa_grid)
-{
-
+                                        ConstVectorView aa_grid) {
   Index n = za_grid.nelem();
   Index m = aa_grid.nelem();
   Vector res1(n);
-  assert (is_size(Integrand, n, m));
-  
-  for (Index i = 0; i < n ; ++i)
-    {
-      res1[i] = 0.0;
-      
-      for (Index j = 0; j < m - 1; ++j)
-        {
-          res1[i] +=  0.5 * DEG2RAD * (Integrand(i, j) + Integrand(i, j + 1)) *
-            (aa_grid[j + 1] - aa_grid[j]) * sin(za_grid[i] * DEG2RAD);
-        }
+  assert(is_size(Integrand, n, m));
+
+  for (Index i = 0; i < n; ++i) {
+    res1[i] = 0.0;
+
+    for (Index j = 0; j < m - 1; ++j) {
+      res1[i] += 0.5 * DEG2RAD * (Integrand(i, j) + Integrand(i, j + 1)) *
+                 (aa_grid[j + 1] - aa_grid[j]) * sin(za_grid[i] * DEG2RAD);
     }
+  }
   Numeric res = 0.0;
-  for (Index i = 0; i < n - 1; ++i)
-    {
-      res += 0.5 * DEG2RAD * (res1[i] + res1[i + 1]) * 
-        (za_grid[i + 1] - za_grid[i]);
-    }
-  
+  for (Index i = 0; i < n - 1; ++i) {
+    res +=
+        0.5 * DEG2RAD * (res1[i] + res1[i + 1]) * (za_grid[i + 1] - za_grid[i]);
+  }
+
   //cout<<res<<"\n";
   return res;
 }
@@ -259,31 +257,26 @@ Numeric AngIntegrate_trapezoid_original(MatrixView Integrand,
 
 Numeric AngIntegrate_trapezoid_opt(MatrixView Integrand,
                                    ConstVectorView za_grid,
-                                   ConstVectorView aa_grid)
-{
-
+                                   ConstVectorView aa_grid) {
   Index n = za_grid.nelem();
   Index m = aa_grid.nelem();
   Vector res1(n);
-  assert (is_size(Integrand, n, m));
-  
-  for (Index i = 0; i < n ; ++i)
-    {
-      res1[i] = 0.0;
+  assert(is_size(Integrand, n, m));
 
-      for (Index j = 0; j < m - 1; ++j)
-        {
-          res1[i] +=  0.5 * DEG2RAD * (Integrand(i, j) + Integrand(i, j + 1)) *
-            (aa_grid[j + 1] - aa_grid[j]) * sin(za_grid[i] * DEG2RAD);
-        }
+  for (Index i = 0; i < n; ++i) {
+    res1[i] = 0.0;
+
+    for (Index j = 0; j < m - 1; ++j) {
+      res1[i] += 0.5 * DEG2RAD * (Integrand(i, j) + Integrand(i, j + 1)) *
+                 (aa_grid[j + 1] - aa_grid[j]) * sin(za_grid[i] * DEG2RAD);
     }
+  }
   Numeric res = 0.0;
-  for (Index i = 0; i < n - 1; ++i)
-    {
-      res += 0.5 * DEG2RAD * (res1[i] + res1[i + 1]) * 
-        (za_grid[i + 1] - za_grid[i]);
-    }
-  
+  for (Index i = 0; i < n - 1; ++i) {
+    res +=
+        0.5 * DEG2RAD * (res1[i] + res1[i + 1]) * (za_grid[i + 1] - za_grid[i]);
+  }
+
   //cout<<res<<"\n";
   return res;
 }
@@ -304,29 +297,25 @@ Numeric AngIntegrate_trapezoid_opt(MatrixView Integrand,
 Numeric AngIntegrate_trapezoid_fixedstep(MatrixView Integrand,
                                          ConstVectorView za_grid,
                                          ConstVectorView aa_grid,
-                                         Numeric stepsize)
-{
+                                         Numeric stepsize) {
   Index n = za_grid.nelem();
   Index m = aa_grid.nelem();
   Vector res1(n);
-  assert (is_size(Integrand, n, m));
-  
-  for (Index i = 0; i < n ; ++i)
-    {
-      res1[i] = 0.0;
-      
-      for (Index j = 0; j < m - 1; ++j)
-        {
-          res1[i] +=  0.5 * DEG2RAD * (Integrand(i, j) + Integrand(i, j + 1)) *
-            stepsize * sin(za_grid[i] * DEG2RAD);
-        }
+  assert(is_size(Integrand, n, m));
+
+  for (Index i = 0; i < n; ++i) {
+    res1[i] = 0.0;
+
+    for (Index j = 0; j < m - 1; ++j) {
+      res1[i] += 0.5 * DEG2RAD * (Integrand(i, j) + Integrand(i, j + 1)) *
+                 stepsize * sin(za_grid[i] * DEG2RAD);
     }
+  }
   Numeric res = 0.0;
-  for (Index i = 0; i < n - 1; ++i)
-    {
-      res += 0.5 * DEG2RAD * (res1[i] + res1[i + 1]) * stepsize;
-    }
-  
+  for (Index i = 0; i < n - 1; ++i) {
+    res += 0.5 * DEG2RAD * (res1[i] + res1[i + 1]) * stepsize;
+  }
+
   //cout<<res<<"\n";
   return res;
 }
@@ -347,39 +336,34 @@ Numeric AngIntegrate_trapezoid_fixedstep(MatrixView Integrand,
 Numeric AngIntegrate_trapezoid_fixedstep_opt(MatrixView Integrand,
                                              ConstVectorView za_grid,
                                              ConstVectorView aa_grid,
-                                             Numeric stepsize)
-{
+                                             Numeric stepsize) {
   Index n = za_grid.nelem();
   Index m = aa_grid.nelem();
   Vector res1(n);
-  assert (is_size(Integrand, n, m));
-  
-  for (Index i = 0; i < n ; ++i)
-    {
-      res1[i] = 0.0;
+  assert(is_size(Integrand, n, m));
 
-      res1[i] += Integrand(i, 0);
-      for (Index j = 1; j < m - 1; j++)
-        {
-          res1[i] += Integrand(i, j) * 2;
-        }
-      res1[i] += Integrand(i, m-1);
-      res1[i] *= 0.5 * DEG2RAD * stepsize * sin(za_grid[i] * DEG2RAD);
+  for (Index i = 0; i < n; ++i) {
+    res1[i] = 0.0;
+
+    res1[i] += Integrand(i, 0);
+    for (Index j = 1; j < m - 1; j++) {
+      res1[i] += Integrand(i, j) * 2;
     }
+    res1[i] += Integrand(i, m - 1);
+    res1[i] *= 0.5 * DEG2RAD * stepsize * sin(za_grid[i] * DEG2RAD);
+  }
   Numeric res = 0.0;
   res += res1[0];
-  for (Index i = 1; i < n - 1; i++)
-    {
-      res += res1[i] * 2;
-    }
-  res += res1[n-1];
+  for (Index i = 1; i < n - 1; i++) {
+    res += res1[i] * 2;
+  }
+  res += res1[n - 1];
   res *= 0.5 * DEG2RAD * stepsize;
-  
+
   //cout<<res<<"\n";
   return res;
 }
 
-
 //! AngIntegrate_trapezoid_fixedstep_opt2
 /*! 
     Performs an integration of a matrix over all directions defined in angular
@@ -397,59 +381,52 @@ Numeric AngIntegrate_trapezoid_fixedstep_opt(MatrixView Integrand,
 Numeric AngIntegrate_trapezoid_fixedstep_opt2(MatrixView Integrand,
                                               ConstVectorView za_grid,
                                               ConstVectorView aa_grid,
-                                              Numeric stepsize)
-{
+                                              Numeric stepsize) {
   Index n = za_grid.nelem();
   Index m = aa_grid.nelem();
   Vector res1(n);
-  assert (is_size(Integrand, n, m));
+  assert(is_size(Integrand, n, m));
 
   Numeric temp = 0.0;
 
-  for (Index i = 0; i < n ; ++i)
-    {
-      temp = Integrand(i, 0);
-      for (Index j = 1; j < m - 1; j++)
-        {
-          temp += Integrand(i, j) * 2;
-        }
-      temp += Integrand(i, m-1);
-      temp *= 0.5 * DEG2RAD * stepsize * sin(za_grid[i] * DEG2RAD);
-      res1[i] = temp;
+  for (Index i = 0; i < n; ++i) {
+    temp = Integrand(i, 0);
+    for (Index j = 1; j < m - 1; j++) {
+      temp += Integrand(i, j) * 2;
     }
+    temp += Integrand(i, m - 1);
+    temp *= 0.5 * DEG2RAD * stepsize * sin(za_grid[i] * DEG2RAD);
+    res1[i] = temp;
+  }
 
   Numeric res = res1[0];
-  for (Index i = 1; i < n - 1; i++)
-    {
-      res += res1[i] * 2;
-    }
-  res += res1[n-1];
+  for (Index i = 1; i < n - 1; i++) {
+    res += res1[i] * 2;
+  }
+  res += res1[n - 1];
   res *= 0.5 * DEG2RAD * stepsize;
-  
+
   //cout<<res<<"\n";
   return res;
 }
 
-
 //! AngIntegration_trapezoid_original
 /*!
   The original function from math_funcs.cc
 */
 Numeric AngIntegrate_trapezoid_original(ConstVectorView Integrand,
-                                        ConstVectorView za_grid)
-{
-
+                                        ConstVectorView za_grid) {
   Index n = za_grid.nelem();
-  assert (is_size(Integrand, n));
-  
+  assert(is_size(Integrand, n));
+
   Numeric res = 0.0;
-  for (Index i = 0; i < n - 1; ++i)
-    {
-      // in this place 0.5 * 2 * PI is calculated:
-      res += PI * DEG2RAD * (Integrand[i]* sin(za_grid[i] * DEG2RAD) 
-                             + Integrand[i + 1] * sin(za_grid[i + 1] * DEG2RAD))
-        * (za_grid[i + 1] - za_grid[i]);
-    }
+  for (Index i = 0; i < n - 1; ++i) {
+    // in this place 0.5 * 2 * PI is calculated:
+    res += PI * DEG2RAD *
+           (Integrand[i] * sin(za_grid[i] * DEG2RAD) +
+            Integrand[i + 1] * sin(za_grid[i + 1] * DEG2RAD)) *
+           (za_grid[i + 1] - za_grid[i]);
+  }
 
   //cout<<res<<"\n";
   return res;
@@ -461,21 +438,18 @@ Numeric AngIntegrate_trapezoid_original(ConstVectorView Integrand,
 */
 Numeric AngIntegrate_trapezoid_fixedstep(ConstVectorView Integrand,
                                          ConstVectorView za_grid,
-                                         Numeric stepsize)
-{
-
+                                         Numeric stepsize) {
   Index n = za_grid.nelem();
-  assert (is_size(Integrand, n));
-  
+  assert(is_size(Integrand, n));
+
   Numeric res = 0.0;
   // cout << "Stepsize: " << stepsize << endl;
   res += (Integrand[0] * sin(za_grid[0] * DEG2RAD));
-  for (Index i = 1; i < n - 1 ; ++i)
-    {
-      res += (Integrand[i] * sin(za_grid[i] * DEG2RAD) * 2);
-      // cout << i << endl;
-    }
-  res += ((Integrand[n-1] * sin(za_grid[n-1] * DEG2RAD)));
+  for (Index i = 1; i < n - 1; ++i) {
+    res += (Integrand[i] * sin(za_grid[i] * DEG2RAD) * 2);
+    // cout << i << endl;
+  }
+  res += ((Integrand[n - 1] * sin(za_grid[n - 1] * DEG2RAD)));
   // cout << n-1 << endl;
   // normally ther would be a 2* here, but it's already in the equations above
   res *= PI * DEG2RAD * stepsize;
@@ -484,7 +458,6 @@ Numeric AngIntegrate_trapezoid_fixedstep(ConstVectorView Integrand,
   return res;
 }
 
-
 //! test_xy
 /*! 
     Performs an integration over a simple Function given by a Matrix
@@ -497,13 +470,11 @@ Numeric AngIntegrate_trapezoid_fixedstep(ConstVectorView Integrand,
 
     \return The resulting integral
 */
-Numeric test_xy(int z_size, int a_size,
-                float stepsize, int frequency)
-{
+Numeric test_xy(int z_size, int a_size, float stepsize, int frequency) {
   cout << ">>>>>-----------test_xy---------------\n";
-  Matrix Integrand(z_size, a_size); // function to be integrated
-  Vector za_grid(z_size);     // zenith (Theta) values
-  Vector aa_grid(a_size);     // azimuth (Phi) values
+  Matrix Integrand(z_size, a_size);  // function to be integrated
+  Vector za_grid(z_size);            // zenith (Theta) values
+  Vector aa_grid(a_size);            // azimuth (Phi) values
 
   init_xy(stepsize, frequency, Integrand, za_grid, aa_grid);
 
@@ -520,23 +491,22 @@ Numeric test_xy(int z_size, int a_size,
 
   gettimeofday(&ende, NULL);
 
-  double error = result/(4*PI) - 1;
+  double error = result / (4 * PI) - 1;
 
-  double diffs = (double)(ende.tv_sec - start.tv_sec)
-    + (double)(ende.tv_usec - start.tv_usec)/1000000.0;
+  double diffs = (double)(ende.tv_sec - start.tv_sec) +
+                 (double)(ende.tv_usec - start.tv_usec) / 1000000.0;
   cout.precision(15);
   cout << "stepsize is    : " << stepsize << endl
        << "z_size         : " << z_size << endl
        << "a_size         : " << a_size << endl
-       << "1 is           : " << result/(4*PI) << endl
+       << "1 is           : " << result / (4 * PI) << endl
        << "The result is  : " << result << endl
-       << "The error is   : " << error*100 << " %\n"
+       << "The error is   : " << error * 100 << " %\n"
        << "Number of loops: " << frequency << endl
        << "elapsed time   : " << diffs << "s" << endl
        << "----------------test_xy----------<<<<<\n";
 
   return result;
-
 }
 
 //! test_xy_opt
@@ -551,13 +521,11 @@ Numeric test_xy(int z_size, int a_size,
 
     \return The resulting integral
 */
-Numeric test_xy_opt(int z_size, int a_size,
-                    float stepsize, int frequency)
-{
+Numeric test_xy_opt(int z_size, int a_size, float stepsize, int frequency) {
   cout << ">>>>>-----------test_xy_opt---------------\n";
-  Matrix Integrand(z_size, a_size); // function to be integrated
-  Vector za_grid(z_size);     // zenith (Theta) values
-  Vector aa_grid(a_size);     // azimuth (Phi) values
+  Matrix Integrand(z_size, a_size);  // function to be integrated
+  Vector za_grid(z_size);            // zenith (Theta) values
+  Vector aa_grid(a_size);            // azimuth (Phi) values
 
   init_xy(stepsize, frequency, Integrand, za_grid, aa_grid);
 
@@ -574,23 +542,22 @@ Numeric test_xy_opt(int z_size, int a_size,
 
   gettimeofday(&ende, NULL);
 
-  double error = result/(4*PI) - 1;
+  double error = result / (4 * PI) - 1;
 
-  double diffs = (double)(ende.tv_sec - start.tv_sec)
-    + (double)(ende.tv_usec - start.tv_usec)/1000000.0;
+  double diffs = (double)(ende.tv_sec - start.tv_sec) +
+                 (double)(ende.tv_usec - start.tv_usec) / 1000000.0;
   cout.precision(15);
   cout << "stepsize is    : " << stepsize << endl
        << "z_size         : " << z_size << endl
        << "a_size         : " << a_size << endl
-       << "1 is           : " << result/(4*PI) << endl
+       << "1 is           : " << result / (4 * PI) << endl
        << "The result is  : " << result << endl
-       << "The error is   : " << error*100 << " %\n"
+       << "The error is   : " << error * 100 << " %\n"
        << "Number of loops: " << frequency << endl
        << "elapsed time   : " << diffs << "s" << endl
        << "----------------test_xy_opt----------<<<<<\n";
 
   return result;
-
 }
 
 //! test_xy_fixedstep
@@ -605,13 +572,14 @@ Numeric test_xy_opt(int z_size, int a_size,
 
     \return The resulting integral
 */
-Numeric test_xy_fixedstep(int z_size, int a_size,
-                          float stepsize, int frequency)
-{
+Numeric test_xy_fixedstep(int z_size,
+                          int a_size,
+                          float stepsize,
+                          int frequency) {
   cout << ">>>>>-----------test_xy_fixedstep---------------\n";
-  Matrix Integrand(z_size, a_size); // function to be integrated
-  Vector za_grid(z_size);     // zenith (Theta) values
-  Vector aa_grid(a_size);     // azimuth (Phi) values
+  Matrix Integrand(z_size, a_size);  // function to be integrated
+  Vector za_grid(z_size);            // zenith (Theta) values
+  Vector aa_grid(a_size);            // azimuth (Phi) values
 
   init_xy(stepsize, frequency, Integrand, za_grid, aa_grid);
 
@@ -624,28 +592,28 @@ Numeric test_xy_fixedstep(int z_size, int a_size,
   //   << "Milisekunden: " << start.tv_usec << endl;
 
   for (int i = 0; i < frequency; i++)
-    result = AngIntegrate_trapezoid_fixedstep(Integrand, za_grid, aa_grid, stepsize);
+    result =
+        AngIntegrate_trapezoid_fixedstep(Integrand, za_grid, aa_grid, stepsize);
 
   gettimeofday(&ende, NULL);
 
-  double error = result/(4*PI) - 1;
+  double error = result / (4 * PI) - 1;
 
-  double diffs = (double)(ende.tv_sec - start.tv_sec)
-    + (double)(ende.tv_usec - start.tv_usec)/1000000.0;
+  double diffs = (double)(ende.tv_sec - start.tv_sec) +
+                 (double)(ende.tv_usec - start.tv_usec) / 1000000.0;
   cout.precision(15);
   cout << diffs << endl;
   cout << "stepsize is    : " << stepsize << endl
        << "z_size         : " << z_size << endl
        << "a_size         : " << a_size << endl
-       << "1 is           : " << result/(4*PI) << endl
+       << "1 is           : " << result / (4 * PI) << endl
        << "The result is  : " << result << endl
-       << "The error is   : " << error*100 << " %\n"
+       << "The error is   : " << error * 100 << " %\n"
        << "Number of loops: " << frequency << endl
        << "elapsed time   : " << diffs << "s" << endl
        << "----------------test_xy_fixedstep----------<<<<<\n";
 
   return result;
-
 }
 
 //! test_xy_fixedstep_opt
@@ -660,13 +628,14 @@ Numeric test_xy_fixedstep(int z_size, int a_size,
 
     \return The resulting integral
 */
-Numeric test_xy_fixedstep_opt(int z_size, int a_size,
-                              float stepsize, int frequency)
-{
+Numeric test_xy_fixedstep_opt(int z_size,
+                              int a_size,
+                              float stepsize,
+                              int frequency) {
   cout << ">>>>>-----------test_xy_fixedstep_opt---------------\n";
-  Matrix Integrand(z_size, a_size); // function to be integrated
-  Vector za_grid(z_size);     // zenith (Theta) values
-  Vector aa_grid(a_size);     // azimuth (Phi) values
+  Matrix Integrand(z_size, a_size);  // function to be integrated
+  Vector za_grid(z_size);            // zenith (Theta) values
+  Vector aa_grid(a_size);            // azimuth (Phi) values
 
   init_xy(stepsize, frequency, Integrand, za_grid, aa_grid);
 
@@ -679,22 +648,23 @@ Numeric test_xy_fixedstep_opt(int z_size, int a_size,
   //   << "Milisekunden: " << start.tv_usec << endl;
 
   for (int i = 0; i < frequency; i++)
-    result = AngIntegrate_trapezoid_fixedstep_opt(Integrand, za_grid, aa_grid, stepsize);
+    result = AngIntegrate_trapezoid_fixedstep_opt(
+        Integrand, za_grid, aa_grid, stepsize);
 
   gettimeofday(&ende, NULL);
 
-  double error = result/(4*PI) - 1;
+  double error = result / (4 * PI) - 1;
 
-  double diffs = (double)(ende.tv_sec - start.tv_sec)
-    + (double)(ende.tv_usec - start.tv_usec)/1000000.0;
+  double diffs = (double)(ende.tv_sec - start.tv_sec) +
+                 (double)(ende.tv_usec - start.tv_usec) / 1000000.0;
   cout.precision(15);
   cout << diffs << endl;
   cout << "stepsize is    : " << stepsize << endl
        << "z_size         : " << z_size << endl
        << "a_size         : " << a_size << endl
-       << "1 is           : " << result/(4*PI) << endl
+       << "1 is           : " << result / (4 * PI) << endl
        << "The result is  : " << result << endl
-       << "The error is   : " << error*100 << " %\n"
+       << "The error is   : " << error * 100 << " %\n"
        << "Number of loops: " << frequency << endl
        << "elapsed time   : " << diffs << "s" << endl
        << "----------------test_xy_fixedstep_opt----------<<<<<\n";
@@ -702,7 +672,6 @@ Numeric test_xy_fixedstep_opt(int z_size, int a_size,
   return result;
 }
 
-
 //! test_xy_fixedstep_opt2
 /*! 
     Performs an integration over a simple Function given by a Matrix
@@ -715,13 +684,14 @@ Numeric test_xy_fixedstep_opt(int z_size, int a_size,
 
     \return The resulting integral
 */
-Numeric test_xy_fixedstep_opt2(int z_size, int a_size,
-                               float stepsize, int frequency)
-{
+Numeric test_xy_fixedstep_opt2(int z_size,
+                               int a_size,
+                               float stepsize,
+                               int frequency) {
   cout << ">>>>>-----------test_xy_fixedstep_opt2---------------\n";
-  Matrix Integrand(z_size, a_size); // function to be integrated
-  Vector za_grid(z_size);     // zenith (Theta) values
-  Vector aa_grid(a_size);     // azimuth (Phi) values
+  Matrix Integrand(z_size, a_size);  // function to be integrated
+  Vector za_grid(z_size);            // zenith (Theta) values
+  Vector aa_grid(a_size);            // azimuth (Phi) values
 
   init_xy(stepsize, frequency, Integrand, za_grid, aa_grid);
 
@@ -734,22 +704,23 @@ Numeric test_xy_fixedstep_opt2(int z_size, int a_size,
   //   << "Milisekunden: " << start.tv_usec << endl;
 
   for (int i = 0; i < frequency; i++)
-    result = AngIntegrate_trapezoid_fixedstep_opt2(Integrand, za_grid, aa_grid, stepsize);
+    result = AngIntegrate_trapezoid_fixedstep_opt2(
+        Integrand, za_grid, aa_grid, stepsize);
 
   gettimeofday(&ende, NULL);
 
-  double error = result/(4*PI) - 1;
+  double error = result / (4 * PI) - 1;
 
-  double diffs = (double)(ende.tv_sec - start.tv_sec)
-    + (double)(ende.tv_usec - start.tv_usec)/1000000.0;
+  double diffs = (double)(ende.tv_sec - start.tv_sec) +
+                 (double)(ende.tv_usec - start.tv_usec) / 1000000.0;
   cout.precision(15);
   cout << diffs << endl;
   cout << "stepsize is    : " << stepsize << endl
        << "z_size         : " << z_size << endl
        << "a_size         : " << a_size << endl
-       << "1 is           : " << result/(4*PI) << endl
+       << "1 is           : " << result / (4 * PI) << endl
        << "The result is  : " << result << endl
-       << "The error is   : " << error*100 << " %\n"
+       << "The error is   : " << error * 100 << " %\n"
        << "Number of loops: " << frequency << endl
        << "elapsed time   : " << diffs << "s" << endl
        << "----------------test_xy_fixedstep_opt2----------<<<<<\n";
@@ -771,13 +742,14 @@ Numeric test_xy_fixedstep_opt2(int z_size, int a_size,
 
     \return The resulting integral
 */
-Numeric test_AngIntegrate_trapezoid_opti(int z_size, int a_size,
-                                         float stepsize, int frequency)
-{
+Numeric test_AngIntegrate_trapezoid_opti(int z_size,
+                                         int a_size,
+                                         float stepsize,
+                                         int frequency) {
   cout << ">>>>>-----------test_AngIntegrate_trapezoid_opti---------------\n";
-  Matrix Integrand(z_size, a_size); // function to be integrated
-  Vector za_grid(z_size);     // zenith (Theta) values
-  Vector aa_grid(a_size);     // azimuth (Phi) values
+  Matrix Integrand(z_size, a_size);  // function to be integrated
+  Vector za_grid(z_size);            // zenith (Theta) values
+  Vector aa_grid(a_size);            // azimuth (Phi) values
 
   Vector grid_stepsize(2);
 
@@ -801,22 +773,23 @@ Numeric test_AngIntegrate_trapezoid_opti(int z_size, int a_size,
   //   << "Milisekunden: " << start.tv_usec << endl;
 
   for (int i = 0; i < frequency; i++)
-    result = AngIntegrate_trapezoid_opti(Integrand, za_grid, aa_grid, grid_stepsize);
+    result =
+        AngIntegrate_trapezoid_opti(Integrand, za_grid, aa_grid, grid_stepsize);
 
   gettimeofday(&ende, NULL);
 
-  double error = result/(4*PI) - 1;
+  double error = result / (4 * PI) - 1;
 
-  double diffs = (double)(ende.tv_sec - start.tv_sec)
-    + (double)(ende.tv_usec - start.tv_usec)/1000000.0;
+  double diffs = (double)(ende.tv_sec - start.tv_sec) +
+                 (double)(ende.tv_usec - start.tv_usec) / 1000000.0;
   cout.precision(15);
   cout << diffs << endl;
   cout << "stepsize is    : " << stepsize << endl
        << "z_size         : " << z_size << endl
        << "a_size         : " << a_size << endl
-       << "1 is           : " << result/(4*PI) << endl
+       << "1 is           : " << result / (4 * PI) << endl
        << "The result is  : " << result << endl
-       << "The error is   : " << error*100 << " %\n"
+       << "The error is   : " << error * 100 << " %\n"
        << "Number of loops: " << frequency << endl
        << "elapsed time   : " << diffs << "s" << endl
        << "----------------test_AngIntegrate_trapezoid_opti----------<<<<<\n";
@@ -824,8 +797,6 @@ Numeric test_AngIntegrate_trapezoid_opti(int z_size, int a_size,
   return result;
 }
 
-
-
 //! test_x
 /*! 
     Performs an integration over a simple Function y=x given by a Vector
@@ -837,13 +808,10 @@ Numeric test_AngIntegrate_trapezoid_opti(int z_size, int a_size,
 
     \return The resulting integral
 */
-Numeric test_x(int vsize,
-                float stepsize,
-                int frequency)
-{
+Numeric test_x(int vsize, float stepsize, int frequency) {
   cout << ">>>>>-----------test_x---------------\n";
-  Vector Integrand(vsize); // function to be integrated
-  Vector Theta(vsize);     // Theta values
+  Vector Integrand(vsize);  // function to be integrated
+  Vector Theta(vsize);      // Theta values
 
   init_x(vsize, stepsize, frequency, Integrand, Theta);
 
@@ -861,27 +829,24 @@ Numeric test_x(int vsize,
   gettimeofday(&ende, NULL);
 
   // norming the result to Pi
-  result = result / (2*180);
+  result = result / (2 * 180);
 
-  double error = result/PI - 1;
+  double error = result / PI - 1;
 
-
-
-  double diffs = (double)(ende.tv_sec - start.tv_sec)
-    + (double)(ende.tv_usec - start.tv_usec)/1000000.0;
+  double diffs = (double)(ende.tv_sec - start.tv_sec) +
+                 (double)(ende.tv_usec - start.tv_usec) / 1000000.0;
   cout.precision(15);
   cout << diffs << endl;
   cout << "stepsize is    : " << stepsize << endl
        << "number of steps: " << vsize << endl
-       << "1 is           : " << PI/PI << endl
-       << "The result is  : " << result/PI << endl
-       << "The error is   : " << error*100 << "%\n"
+       << "1 is           : " << PI / PI << endl
+       << "The result is  : " << result / PI << endl
+       << "The error is   : " << error * 100 << "%\n"
        << "Number of loops: " << frequency << endl
        << "elapsed time   : " << diffs << "s" << endl
        << "---------------test_x-----------<<<<<\n";
 
   return result;
-
 }
 //! test_x_fixedstep
 /*! 
@@ -893,30 +858,27 @@ Numeric test_x(int vsize,
 
     \return The resulting integral
 */
-Numeric test_x_fixedstep(int vsize,
-              int frequency)
-{
+Numeric test_x_fixedstep(int vsize, int frequency) {
   cout << ">>>>>-----------test_x_fixedstep---------------\n";
   cout.precision(12);
-  Vector Integrand(vsize); // function to be integrated
-  Vector Theta(vsize);     // Theta values
+  Vector Integrand(vsize);  // function to be integrated
+  Vector Theta(vsize);      // Theta values
 
   double stepsize;
-  stepsize = 180.0 / (vsize - 1);  // attention this only works with eaqually spaced intervals
+  stepsize =
+      180.0 /
+      (vsize - 1);  // attention this only works with eaqually spaced intervals
   cout << "Neue berechnete Stepsize: " << stepsize << endl;
 
-  for (int i = 0; i < Integrand.nelem(); i++)
-    Integrand[i] = i * stepsize;
+  for (int i = 0; i < Integrand.nelem(); i++) Integrand[i] = i * stepsize;
 
   //Theta is between 0 and 180
-  for (int i = 0; i < Theta.nelem(); i++)
-    Theta[i] = i * stepsize;
-
+  for (int i = 0; i < Theta.nelem(); i++) Theta[i] = i * stepsize;
 
   cout << "Integrand: von " << Integrand[0] << " bis "
        << Integrand[Integrand.nelem() - 1] << endl
-       << "Theta: von " << Theta[0] << " bis "
-       << Theta[Theta.nelem() - 1] << endl;
+       << "Theta: von " << Theta[0] << " bis " << Theta[Theta.nelem() - 1]
+       << endl;
 
   Numeric result = 0;
 
@@ -932,25 +894,22 @@ Numeric test_x_fixedstep(int vsize,
   gettimeofday(&ende, NULL);
 
   // norming the result to Pi
-  result = result / (2*180);
+  result = result / (2 * 180);
 
-  double error = result/PI - 1;
+  double error = result / PI - 1;
 
-
-
-  double diffs = (double)(ende.tv_sec - start.tv_sec)
-    + (double)(ende.tv_usec - start.tv_usec)/1000000.0;
+  double diffs = (double)(ende.tv_sec - start.tv_sec) +
+                 (double)(ende.tv_usec - start.tv_usec) / 1000000.0;
   cout.precision(15);
   cout << diffs << endl;
   cout << "stepsize is    : " << stepsize << endl
        << "number of steps: " << vsize << endl
-       << "1 is          : " << PI/PI << endl
-       << "The result is  : " << result/PI << endl
-       << "The error is   : " << error*100 << "%\n"
+       << "1 is          : " << PI / PI << endl
+       << "The result is  : " << result / PI << endl
+       << "The error is   : " << error * 100 << "%\n"
        << "Number of loops: " << frequency << endl
        << "elapsed time   : " << diffs << "s" << endl
        << "---------------test_x_fixedstep----------<<<<<\n";
 
   return result;
-
 }
